Learn R Programming

traktok (version 0.1.1)

tt_get_following_hidden: Get followers and following of a user from the hidden API

Description

[Works on: Unofficial API]

Get up to 5,000 accounts who follow a user or accounts a user follows.

Usage

tt_get_following_hidden(
  secuid,
  sleep_pool = 1:10,
  max_tries = 5L,
  cookiefile = NULL,
  verbose = interactive()
)

tt_get_follower_hidden( secuid, sleep_pool = 1:10, max_tries = 5L, cookiefile = NULL, verbose = interactive() )

Value

a data.frame of followers

Arguments

secuid

The secuid of a user. You can get it with tt_user_info_hidden by querying an account (see example).

sleep_pool

a vector of numbers from which a waiting period is randomly drawn.

max_tries

how often to retry if a request fails.

cookiefile

path to your cookiefile. Usually not needed after running auth_hidden once. See vignette("unofficial-api", package = "traktok") for more information on authentication.

verbose

should the function print status updates to the screen?

Examples

Run this code
if (FALSE) {
df <- tt_user_info_hidden("https://www.tiktok.com/@fpoe_at")
tt_get_follower_hidden(df$secUid)
}

Run the code above in your browser using DataLab