Learn R Programming

traktok (version 0.1.1)

tt_user_pinned_videos_api: Lookup which videos were pinned by a user using the research API

Description

[Works on: Research API]

Usage

tt_user_pinned_videos_api(
  username,
  fields = "all",
  cache = TRUE,
  verbose = interactive(),
  token = NULL
)

tt_get_pinned( username, fields = "all", cache = TRUE, verbose = interactive(), token = NULL )

Value

A data.frame of parsed TikTok videos the user has posted.

Arguments

username

vector of user names (handles) or URLs to users' pages.

fields

The fields to be returned (defaults to all)

cache

should progress be saved in the current session? It can then be retrieved with last_query() if an error occurs. But the function will use extra memory.

verbose

should the function print status updates to the screen?

token

The authentication token (usually supplied automatically after running auth_research once).

Examples

Run this code
if (FALSE) {
tt_get_pinned("jbgruber")
# OR
tt_user_pinned_videos_api("https://www.tiktok.com/@tiktok")
# OR
tt_user_pinned_videos_api("https://www.tiktok.com/@tiktok")
}

Run the code above in your browser using DataLab