Learn R Programming

traktok (version 0.1.1)

tt_user_reposted_api: Lookup which videos were liked by a user using the research API

Description

[Works on: Research API]

Usage

tt_user_reposted_api(
  username,
  fields = "all",
  max_pages = 1,
  cache = TRUE,
  verbose = interactive(),
  token = NULL
)

tt_get_reposted( username, fields = "all", max_pages = 1, cache = TRUE, verbose = interactive(), token = NULL )

Value

A data.frame of parsed TikTok videos the user has posted.

Arguments

username

name(s) of the user(s) to be queried

fields

The fields to be returned (defaults to all)

max_pages

results are returned in batches/pages with 100 videos. How many should be requested before the function stops?

cache

should progress be saved in the current session? It can then be retrieved with last_query() if an error occurs. But the function will use extra memory.

verbose

should the function print status updates to the screen?

token

The authentication token (usually supplied automatically after running auth_research once).

Examples

Run this code
if (FALSE) {
tt_get_reposted("jbgruber")
# OR
tt_user_reposted_api("https://www.tiktok.com/@tiktok")
# OR
tt_user_reposted_api("https://www.tiktok.com/@tiktok")

# note: none of these work because nobody has this enabled!
}

Run the code above in your browser using DataLab