The secuid of a user. You can get it with
tt_user_info_hidden by querying an account (see example).
sleep_pool
a vector of numbers from which a waiting period is randomly
drawn.
max_tries
how often to retry if a request fails.
cookiefile
path to your cookiefile. Usually not needed after running
auth_hidden once. See vignette("unofficial-api", package =
"traktok") for more information on authentication.
verbose
should the function print status updates to the screen?